==> eiffelstudio-18.11.10.2592.tar: F_code/C4/ew168.c <==
/*
 * Code for class EW_OPERATING_SYSTEM
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ew168.h"
#include "eif_built_in.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {EW_OPERATING_SYSTEM}.full_file_name */
EIF_REFERENCE F203_2537 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(5);
	RTLR(0,tr1);
	RTLR(1,arg1);
	RTLR(2,arg2);
	RTLR(3,Result);
	RTLR(4,Current);
	RTLIU(5);
	
	RTEAA("full_file_name", 202, Current, 0, 2, 2609);
	RTGC;
	RTHOOK(1);
	tr1 = RTLNS(eif_new_type(752, 0x00).id, 752, _OBJSIZ_2_1_0_0_0_0_0_0_);
	F753_4201(RTCW(tr1), arg1);
	Result = F753_4228(RTCW(tr1), arg2);
	Result = F753_4240(RTCW(Result));
	RTHOOK(3);
	RTLE;
	RTEE;
	return Result;
}

/* {EW_OPERATING_SYSTEM}.delete_directory_tree */
#undef EIF_VOLATILE
#define EIF_VOLATILE volatile
void F203_2540 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	RTED;
	EIF_REFERENCE EIF_VOLATILE loc1 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 EIF_VOLATILE loc2 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE EIF_VOLATILE saved_except = (EIF_REFERENCE) 0;
	EIF_REFERENCE  EIF_VOLATILE tr1 = NULL;
	EIF_BOOLEAN  EIF_VOLATILE tb1;
	RTLD;
	RTXD;
	
	RTLI(5);
	RTLR(0,Current);
	RTLR(1,loc1);
	RTLR(2,tr1);
	RTLR(3,arg1);
	RTLR(4,saved_except);
	RTLIU(5);
	RTXSLS;
	
	RTEAA("delete_directory_tree", 202, Current, 2, 1, 2610);
	RTGC;
	RTE_T
	RTHOOK(1);
	if ((EIF_BOOLEAN) (loc2 <= ((EIF_INTEGER_32) 1L))) {
		RTHOOK(2);
		tb1 = '\0';
		if ((EIF_BOOLEAN)(loc2 == ((EIF_INTEGER_32) 1L))) {
			tb1 = (EIF_BOOLEAN) eif_builtin_PLATFORM_is_windows;
		}
		if (tb1) {
			RTHOOK(3);
			F202_2522(Current, (EIF_INTEGER_64) ((EIF_INTEGER_32) 150000000L));
		}
		RTHOOK(4);
		tr1 = RTLNS(eif_new_type(198, 0x00).id, 198, _OBJSIZ_3_0_0_1_0_2_0_0_);
		F199_2384(RTCW(tr1), arg1);
		loc1 = (EIF_REFERENCE) tr1;
		RTHOOK(5);
		tb1 = F199_2408(RTCW(loc1));
		if (tb1) {
			RTHOOK(6);
			F199_2414(RTCW(loc1));
		}
	}
	RTE_E
	RTXSC;
	RTHOOK(7);
	loc2++;
	RTHOOK(8);
	RTER;
	/* NOTREACHED */
	RTE_EE
	RTHOOK(9);
	RTEOK;
	RTLE;
}
#undef EIF_VOLATILE
#define EIF_VOLATILE

/* {EW_OPERATING_SYSTEM}.sleep_milliseconds */
void F203_2542 (EIF_REFERENCE Current, EIF_REAL_64 arg1)
{
	GTCX
	RTEX;
	EIF_REAL_64 tr8_1;
	EIF_INTEGER_64 ti8_1;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("sleep_milliseconds", 202, Current, 0, 1, 2608);
	RTGC;
	RTHOOK(1);
	tr8_1 = (EIF_REAL_64) (((EIF_INTEGER_32) 1000000L));
	ti8_1 = (EIF_INTEGER_64) (EIF_REAL_64) ((EIF_REAL_64) (arg1 * tr8_1) + (EIF_REAL_64) 0.5);
	F202_2522(Current, ti8_1);
	RTHOOK(2);
	RTLE;
	RTEE;
}

void EIF_Minit168 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C4/ew168.c <==
/*
 * Code for class EW_OPERATING_SYSTEM
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ew168.h"
#include "eif_built_in.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {EW_OPERATING_SYSTEM}.full_file_name */
EIF_REFERENCE F203_2539 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	RTEX;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,arg1);
	RTLR(1,arg2);
	RTLR(2,Result);
	RTLR(3,Current);
	RTLIU(4);
	
	RTEAA("full_file_name", 202, Current, 0, 2, 2612);
	RTGC;
	RTHOOK(1);
	Result = RTLNS(eif_new_type(752, 0x00).id, 752, _OBJSIZ_2_1_0_0_0_0_0_0_);
	F753_4208(RTCW(Result), arg1);
	Result = F753_4235(RTCW(Result), arg2);
	Result = F753_4247(RTCW(Result));
	RTHOOK(3);
	RTLE;
	RTEE;
	return Result;
}

/* {EW_OPERATING_SYSTEM}.delete_directory_tree */
#undef EIF_VOLATILE
#define EIF_VOLATILE volatile
void F203_2542 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	RTED;
	EIF_REFERENCE EIF_VOLATILE loc1 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 EIF_VOLATILE loc2 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE EIF_VOLATILE saved_except = (EIF_REFERENCE) 0;
	EIF_REFERENCE  EIF_VOLATILE tr1 = NULL;
	EIF_BOOLEAN  EIF_VOLATILE tb1;
	RTLD;
	RTXD;
	
	RTLI(5);
	RTLR(0,Current);
	RTLR(1,loc1);
	RTLR(2,tr1);
	RTLR(3,arg1);
	RTLR(4,saved_except);
	RTLIU(5);
	RTXSLS;
	
	RTEAA("delete_directory_tree", 202, Current, 2, 1, 2610);
	RTGC;
	RTE_T
	RTHOOK(1);
	if ((EIF_BOOLEAN) (loc2 <= ((EIF_INTEGER_32) 1L))) {
		RTHOOK(2);
		tb1 = '\0';
		if ((EIF_BOOLEAN)(loc2 == ((EIF_INTEGER_32) 1L))) {
			tb1 = (EIF_BOOLEAN) eif_builtin_PLATFORM_is_windows;
		}
		if (tb1) {
			RTHOOK(3);
			F202_2523(Current, (EIF_INTEGER_64) ((EIF_INTEGER_32) 150000000L));
		}
		RTHOOK(4);
		tr1 = RTLNS(eif_new_type(198, 0x00).id, 198, _OBJSIZ_3_0_0_1_0_2_0_0_);
		F199_2384(RTCW(tr1), arg1);
		loc1 = (EIF_REFERENCE) tr1;
		RTHOOK(5);
		tb1 = F199_2408(RTCW(loc1));
		if (tb1) {
			RTHOOK(6);
			F199_2414(RTCW(loc1));
		}
	}
	RTE_E
	RTXSC;
	RTHOOK(7);
	loc2++;
	RTHOOK(8);
	RTER;
	/* NOTREACHED */
	RTE_EE
	RTHOOK(9);
	RTEOK;
	RTLE;
}
#undef EIF_VOLATILE
#define EIF_VOLATILE

/* {EW_OPERATING_SYSTEM}.sleep_milliseconds */
void F203_2544 (EIF_REFERENCE Current, EIF_REAL_64 arg1)
{
	GTCX
	RTEX;
	EIF_REAL_64 tr8_1;
	EIF_INTEGER_64 ti8_1;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("sleep_milliseconds", 202, Current, 0, 1, 2611);
	RTGC;
	RTHOOK(1);
	tr8_1 = (EIF_REAL_64) (((EIF_INTEGER_32) 1000000L));
	ti8_1 = (EIF_INTEGER_64) (EIF_REAL_64) ((EIF_REAL_64) (arg1 * tr8_1) + (EIF_REAL_64) 0.5);
	F202_2523(Current, ti8_1);
	RTHOOK(2);
	RTLE;
	RTEE;
}

void EIF_Minit168 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
